@@ -18,7 +18,9 @@ class TopEventItem(Classified, ElementPresentation):
     def __init__(self, diagram, id=None):
         super().__init__(diagram, id)
 
-        self.watch("subject.name").watch("subject.namespace.name")
+        self.watch("subject[UML:NamedElement].name").watch(
+            "subject[UML:NamedElement].namespace.name"
+        )
 
     def update_shapes(self, event=None):
         self.shape = Box(
