@@ -24,5 +24,7 @@ class ExtendItem(Named, LinePresentation):
         self._handles[0].pos = (30, 20)
         self._handles[1].pos = (0, 0)
 
-        self.watch("subject.appliedStereotype.classifier.name").watch("subject.name")
+        self.watch("subject[Element].appliedStereotype.classifier.name").watch(
+            "subject[NamedElement].name"
+        )
         self.draw_head = draw_arrow_head
