@@ -1,5 +1,6 @@
 from functools import singledispatch
 
+from gaphor.core.modeling import UnlimitedNatural
 from gaphor.core.modeling.coremodel import (
     ElementChange,
     RefChange,
@@ -48,7 +49,8 @@ def _(change: ValueChange, element_factory):
     element = element_factory.lookup(change.element_id)
     return bool(
         element
-        and getattr(element, change.property_name, None) != change.property_value
+        and getattr(element, change.property_name, None)
+        != get_value_change_property_value(change)
     )
 
 
@@ -57,7 +59,7 @@ def _(change: ValueChange, element_factory, modeling_factory):
     if change.applied:
         return
     element = element_factory[change.element_id]
-    element.load(change.property_name, change.property_value)
+    element.load(change.property_name, get_value_change_property_value(change))
     element.postload()
     change.applied = True
 
@@ -97,3 +99,25 @@ def _(change: RefChange, element_factory, modeling_factory):
             None,
         ):
             other.applied = True
+
+
+def get_value_change_property_value(
+    value_change,
+) -> None | str | int | UnlimitedNatural | bool:
+    if value_change.property_value is None:
+        return None
+    elif value_change.property_type == "str":
+        return str(value_change.property_value)
+    elif value_change.property_type == "int":
+        return int(value_change.property_value)
+    elif value_change.property_type == "bool":
+        return bool(value_change.property_value == "True")
+    elif (
+        value_change.property_type == "UnlimitedNatural"
+        and value_change.property_value == "*"
+    ):
+        return "*"
+    elif value_change.property_type == "UnlimitedNatural":
+        return int(value_change.property_value)
+    else:
+        return None
