@@ -7,7 +7,6 @@ class PseudoStyleNode:
     def __init__(self, node: StyleNode, psuedo: str | None):
         self._node = node
         self.pseudo = psuedo
-        self.dark_mode = node.dark_mode
 
     def name(self) -> str:
         return self._node.name()
@@ -24,10 +23,10 @@ class PseudoStyleNode:
     def state(self) -> Sequence[str]:
         return self._node.state()
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash((self._node, self.pseudo))
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         return (
             isinstance(other, PseudoStyleNode)
             and self._node == other._node
