@@ -10,11 +10,14 @@ import itertools
 from collections.abc import Callable, Iterator
 from enum import Enum
 from functools import singledispatch
+from typing import TypeVar
 
 from generic.multidispatch import FunctionDispatcher, multidispatch
 
 from gaphor.core.modeling import Base, Diagram, Presentation
 
+T = TypeVar("T", bound=Base)
+
 
 def self_and_owners(element: Base | RootType | None) -> Iterator[Base]:
     """Return the element and the ancestors (Element.owner)."""
@@ -28,6 +31,15 @@ def self_and_owners(element: Base | RootType | None) -> Iterator[Base]:
         e = owner(e)
 
 
+def owner_of_type[T](element: Base | None, owner_type: type[T]) -> T | None:
+    if element is None or isinstance(element, owner_type):
+        return element
+
+    if (o := owner(element)) is Root:
+        return None
+    return owner_of_type(o, owner_type)
+
+
 def change_owner(new_parent: Base | None, element: Base) -> bool:
     if new_parent and element.model is not new_parent.model:
         return False
@@ -37,7 +49,8 @@ def change_owner(new_parent: Base | None, element: Base) -> bool:
         o = None
 
     if new_parent and o is new_parent:
-        return False
+        # idempotency
+        return True
 
     if new_parent and element in self_and_owners(new_parent):
         return False
@@ -62,7 +75,7 @@ Root = RootType.Root
 
 
 @singledispatch
-def owner(_element: Base) -> Base | RootType | None:
+def owner(_element: Base | RootType | None) -> Base | RootType | None:
     return None
 
 
@@ -110,7 +123,13 @@ def ungroup(parent, element) -> bool:
 
 
 @ungroup.register(None, Base)
-def none_ungroup(none, element):
+def none_base_ungroup(none, element):
     """In the rare (error?) case a model element has no parent, but is grouped
     in a diagram, allow it to ungroup."""
     return True
+
+
+@ungroup.register(Base, None)
+def base_none_ungroup(element, none):
+    """Some elements, such as relationship items can have no subject."""
+    return True
